/// <reference types="react" />
import { Container, ContainerProperties, ContainerState } from '../Container';
/**
 * Component that is allowed to be used on the page by the editor
 */
export interface AllowedComponent {
    /**
     * Path to the component under apps
     */
    path: string;
    /**
     * Title of the component
     */
    title: string;
}
/**
 * AllowedComponents collection
 */
export interface AllowedComponents {
    applicable: boolean;
    /**
     * List of allowed components
     */
    components: AllowedComponent[];
}
/**
 * Properties for the allowed components container
 */
export interface AllowedComponentsProperties extends ContainerProperties {
    /**
     * List of allowed components for the container
     */
    allowedComponents: AllowedComponents;
    /**
     *  Label to display when there are no allowed components
     */
    _allowedComponentPlaceholderListEmptyLabel?: string;
    /**
     * Title of the placeholder list
     */
    title: string;
}
/**
 *  When applicable, the component exposes a list of allowed components
 *  This is used by the template editor
 */
export declare class AllowedComponentsContainer<M extends AllowedComponentsProperties, S extends ContainerState> extends Container<M, S> {
    static defaultProps: {
        _allowedComponentPlaceholderListEmptyLabel: string;
        cqItems: {};
        cqItemsOrder: never[];
        cqPath: string;
    };
    render(): JSX.Element;
}
//# sourceMappingURL=AllowedComponentsContainer.d.ts.map